==> open-xchange-core_7.4.1.orig.tar.bz2: open-xchange-core-7.4.1/com.openexchange.quartz/src/org/quartz/service/osgi/QuartzActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.quartz.service.osgi;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.osgi.framework.ServiceRegistration;
import org.quartz.service.QuartzService;
import org.quartz.service.internal.QuartzServiceImpl;
import org.quartz.service.internal.Services;
import com.hazelcast.core.HazelcastInstance;
import com.openexchange.config.ConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link QuartzActivator}
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 */
public class QuartzActivator extends HousekeepingActivator {

    private volatile ServiceRegistration<QuartzService> quartzServiceRegistration;

    private QuartzServiceImpl quartzServiceImpl;


    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { HazelcastInstance.class, ConfigurationService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);
        final Log log = LogFactory.getLog(QuartzActivator.class);
        log.info("Starting bundle: org.quartz");
        try {
            System.setProperty("org.terracotta.quartz.skipUpdateCheck", "true");
            quartzServiceImpl = new QuartzServiceImpl();
            quartzServiceRegistration = context.registerService(QuartzService.class, quartzServiceImpl, null);
            log.info("Bundle successfully started: org.quartz");
        } catch (final Exception e) {
            log.error("Failed starting bundle: org.quartz", e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        final Log log = LogFactory.getLog(QuartzActivator.class);
        log.info("Stopping bundle: org.quartz");
        try {
            final ServiceRegistration<QuartzService> quartzServiceRegistration = this.quartzServiceRegistration;
            if (null != quartzServiceRegistration) {
                quartzServiceRegistration.unregister();
                this.quartzServiceRegistration = null;
            }

            if (quartzServiceImpl != null) {
                quartzServiceImpl.shutdown();
            }
            log.info("Bundle successfully stopped: org.quartz");
        } catch (final Exception e) {
            log.error("Failed stopping bundle: org.quartz", e);
            throw e;
        }
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.quartz/src/org/quartz/service/osgi/QuartzActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package org.quartz.service.osgi;

import org.apache.commons.logging.LogFactory;
import org.osgi.framework.ServiceRegistration;
import org.quartz.service.QuartzService;
import org.quartz.service.internal.QuartzServiceImpl;
import org.quartz.service.internal.Services;
import com.hazelcast.core.HazelcastInstance;
import com.openexchange.config.ConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;


/**
 * {@link QuartzActivator}
 *
 * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
 */
public class QuartzActivator extends HousekeepingActivator {

    private volatile ServiceRegistration<QuartzService> quartzServiceRegistration;

    private QuartzServiceImpl quartzServiceImpl;


    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { HazelcastInstance.class, ConfigurationService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);
        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(QuartzActivator.class);
        log.info("Starting bundle: org.quartz");
        try {
            System.setProperty("org.terracotta.quartz.skipUpdateCheck", "true");
            quartzServiceImpl = new QuartzServiceImpl();
            quartzServiceRegistration = context.registerService(QuartzService.class, quartzServiceImpl, null);
            log.info("Bundle successfully started: org.quartz");
        } catch (final Exception e) {
            log.error("Failed starting bundle: org.quartz", e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(QuartzActivator.class);
        log.info("Stopping bundle: org.quartz");
        try {
            final ServiceRegistration<QuartzService> quartzServiceRegistration = this.quartzServiceRegistration;
            if (null != quartzServiceRegistration) {
                quartzServiceRegistration.unregister();
                this.quartzServiceRegistration = null;
            }

            if (quartzServiceImpl != null) {
                quartzServiceImpl.shutdown();
            }
            log.info("Bundle successfully stopped: org.quartz");
        } catch (final Exception e) {
            log.error("Failed stopping bundle: org.quartz", e);
            throw e;
        }
    }

}
